# IO.Swagger - the C# library for the its4land Public API

The its4land Public API provides access to the services of the its4land Publish and Share platform.

This C# SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 0.0.2
- SDK version: 1.0.0
- Build package: io.swagger.codegen.languages.CSharpClientCodegen
    For more information, please visit [https://its4land.com](https://its4land.com)

<a name="frameworks-supported"></a>
## Frameworks supported
- .NET 4.0 or later
- Windows Phone 7.1 (Mango)

<a name="dependencies"></a>
## Dependencies
- [RestSharp](https://www.nuget.org/packages/RestSharp) - 105.1.0 or later
- [Json.NET](https://www.nuget.org/packages/Newtonsoft.Json/) - 7.0.0 or later
- [JsonSubTypes](https://www.nuget.org/packages/JsonSubTypes/) - 1.2.0 or later

The DLLs included in the package may not be the latest version. We recommend using [NuGet] (https://docs.nuget.org/consume/installing-nuget) to obtain the latest version of the packages:
```
Install-Package RestSharp
Install-Package Newtonsoft.Json
Install-Package JsonSubTypes
```

NOTE: RestSharp versions greater than 105.1.0 have a bug which causes file uploads to fail. See [RestSharp#742](https://github.com/restsharp/RestSharp/issues/742)

<a name="installation"></a>
## Installation
Run the following command to generate the DLL
- [Mac/Linux] `/bin/sh build.sh`
- [Windows] `build.bat`

Then include the DLL (under the `bin` folder) in the C# project, and use the namespaces:
```csharp
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;
```
<a name="packaging"></a>
## Packaging

A `.nuspec` is included with the project. You can follow the Nuget quickstart to [create](https://docs.microsoft.com/en-us/nuget/quickstart/create-and-publish-a-package#create-the-package) and [publish](https://docs.microsoft.com/en-us/nuget/quickstart/create-and-publish-a-package#publish-the-package) packages.

This `.nuspec` uses placeholders from the `.csproj`, so build the `.csproj` directly:

```
nuget pack -Build -OutputDirectory out IO.Swagger.csproj
```

Then, publish to a [local feed](https://docs.microsoft.com/en-us/nuget/hosting-packages/local-feeds) or [other host](https://docs.microsoft.com/en-us/nuget/hosting-packages/overview) and consume the new package via Nuget as usual.

<a name="getting-started"></a>
## Getting Started

```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class Example
    {
        public void main()
        {

            var apiInstance = new AdminSourcesApi();
            var adminsourceUid = adminsourceUid_example;  // string | AdminSource UID
            var envelope = envelope_example;  // string | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. (optional) 
            var embed = new List<string>(); // List<string> | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) (optional) 

            try
            {
                // Returns a single Admin Source
                AdminSourcesEndpointType result = apiInstance.GetAdminSourceByUID(adminsourceUid, envelope, embed);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling AdminSourcesApi.GetAdminSourceByUID: " + e.Message );
            }

        }
    }
}
```

<a name="documentation-for-api-endpoints"></a>
## Documentation for API Endpoints

All URIs are relative to *https://platform.its4land.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AdminSourcesApi* | [**GetAdminSourceByUID**](docs/AdminSourcesApi.md#getadminsourcebyuid) | **GET** /adminsources/{adminsource_uid} | Returns a single Admin Source
*AdminSourcesApi* | [**GetAdminSources**](docs/AdminSourcesApi.md#getadminsources) | **GET** /adminsources | Returns a list of AdminSource document indizes
*AdminSourcesApi* | [**NewAdminSource**](docs/AdminSourcesApi.md#newadminsource) | **POST** /adminsources | Creates a new AdminSource
*AdminSourcesApi* | [**UpdateAdminSource**](docs/AdminSourcesApi.md#updateadminsource) | **PATCH** /adminsources/{adminsource_uid} | Update an Admin Source
*BoundaryFaceStringApi* | [**GetBoundaryFaceString**](docs/BoundaryFaceStringApi.md#getboundaryfacestring) | **GET** /boundaryfacestring | Returns a list of boundary face strings in a GeoJSON structure.
*BoundaryFaceStringApi* | [**GetBoundaryFaceStringByUID**](docs/BoundaryFaceStringApi.md#getboundaryfacestringbyuid) | **GET** /boundaryfacestring/{boundaryfacestring_uid} | Returns a single boundary face string
*BoundaryFaceStringApi* | [**NewBoundaryFaceString**](docs/BoundaryFaceStringApi.md#newboundaryfacestring) | **POST** /boundaryfacestring | Create a new concept for a boundary face string
*BoundaryFaceStringApi* | [**PutBoundaryFaceStringByUID**](docs/BoundaryFaceStringApi.md#putboundaryfacestringbyuid) | **PUT** /boundaryfacestring/{boundaryfacestring_uid} | Replace an existing BoundaryFaceString by a newer version
*BoundaryFaceStringApi* | [**UpdateBoundaryFaceString**](docs/BoundaryFaceStringApi.md#updateboundaryfacestring) | **PATCH** /boundaryfacestring/{boundaryfacestring_uid} | Updates a boundary face string
*ClassifierApi* | [**GetClassifier**](docs/ClassifierApi.md#getclassifier) | **GET** /classifier | Returns a list of classifier
*ClassifierApi* | [**GetClassifierByUID**](docs/ClassifierApi.md#getclassifierbyuid) | **GET** /classifier/{classifier_id} | Returns a single classifier.
*ClassifierApi* | [**NewClassifier**](docs/ClassifierApi.md#newclassifier) | **POST** /classifier | Create a new classifier
*ContentItemsApi* | [**GetContentItem**](docs/ContentItemsApi.md#getcontentitem) | **GET** /contentitems/{contentitem_id} | Returns a single content from the object storage.
*ContentItemsApi* | [**GetContentItems**](docs/ContentItemsApi.md#getcontentitems) | **GET** /contentitems | Returns a list of contentitems
*ContentItemsApi* | [**NewContentItem**](docs/ContentItemsApi.md#newcontentitem) | **POST** /contentitems | Create a new content in the object storage
*MetricMapFeaturesApi* | [**GetMetricMapFeature**](docs/MetricMapFeaturesApi.md#getmetricmapfeature) | **GET** /metricmapfeature | Returns MetricMapFeature
*MetricMapFeaturesApi* | [**NewMetricMapFeature**](docs/MetricMapFeaturesApi.md#newmetricmapfeature) | **POST** /metricmapfeature | Create a new metricMapFeature
*MetricMapFeaturesApi* | [**UpdateMetricMapFeature**](docs/MetricMapFeaturesApi.md#updatemetricmapfeature) | **PATCH** /metricmapfeature/{mmf_uid} | Updates a metric map feature
*MiscApi* | [**GetDDILayers**](docs/MiscApi.md#getddilayers) | **GET** /DDILayers | Return a list of registered DDI (WFS/WMS) Layer
*MiscApi* | [**GetPuSConfig**](docs/MiscApi.md#getpusconfig) | **GET** /PuSConfig | Returns a list of configuration parameters as Key Value
*MiscApi* | [**NewDDILayers**](docs/MiscApi.md#newddilayers) | **POST** /DDILayers | Register a new DDI (WFS/WMS) Layer
*ModelClassesApi* | [**GetModelClasses**](docs/ModelClassesApi.md#getmodelclasses) | **GET** /modelclasses | Returns ModelClasses
*ModelClassesApi* | [**GetModelClassesByUID**](docs/ModelClassesApi.md#getmodelclassesbyuid) | **GET** /modelclasses/{modelclasses_uid} | Returns a single model class
*ModelClassesApi* | [**UpdateModelClasses**](docs/ModelClassesApi.md#updatemodelclasses) | **PATCH** /modelclasses/{modelclasses_uid} | Updates some attributes of a ModelClass
*ModelsApi* | [**GetModels**](docs/ModelsApi.md#getmodels) | **GET** /models | Returns a list of models.
*ModelsApi* | [**GetModelsByUID**](docs/ModelsApi.md#getmodelsbyuid) | **GET** /models/{model_uid} | Returns a single model
*ModelsApi* | [**GetModelsClassesByModel**](docs/ModelsApi.md#getmodelsclassesbymodel) | **GET** /models/{model_uid}/modelclasses | Returns the model classes of the classifier.
*ModelsApi* | [**NewModel**](docs/ModelsApi.md#newmodel) | **POST** /models | Create a new model
*ModelsApi* | [**NewModelClassUnderModel**](docs/ModelsApi.md#newmodelclassundermodel) | **POST** /models/{model_uid}/modelclasses | Create a new ModelClass under a model
*ModelsApi* | [**UpdateModels**](docs/ModelsApi.md#updatemodels) | **PATCH** /models/{model_uid} | Updates some attributes of a model
*ProcessesApi* | [**CreateProcessLog**](docs/ProcessesApi.md#createprocesslog) | **POST** /processes/{process_uid}/log | Writes a single log entry
*ProcessesApi* | [**CreateProcesses**](docs/ProcessesApi.md#createprocesses) | **POST** /processes | Creates a new  processes
*ProcessesApi* | [**GetProcessByUID**](docs/ProcessesApi.md#getprocessbyuid) | **GET** /processes/{process_uid} | Returns metadata for a single process
*ProcessesApi* | [**GetProcessLog**](docs/ProcessesApi.md#getprocesslog) | **GET** /processes/{process_uid}/log | Get the full log of a process
*ProcessesApi* | [**GetProcesses**](docs/ProcessesApi.md#getprocesses) | **GET** /processes | Get a list of processes
*ProjectsApi* | [**AddTagToProject**](docs/ProjectsApi.md#addtagtoproject) | **POST** /projects/{project_uid}/Tags | Adds a tag to the project
*ProjectsApi* | [**DelProjectByUID**](docs/ProjectsApi.md#delprojectbyuid) | **DELETE** /projects/{project_uid} | Deletes a single e project by its UID
*ProjectsApi* | [**DetachProjectModel**](docs/ProjectsApi.md#detachprojectmodel) | **DELETE** /projects/{project_uid}/Models/{model_uid} | Removes a model from a project.
*ProjectsApi* | [**DetachProjectSpatialSource**](docs/ProjectsApi.md#detachprojectspatialsource) | **DELETE** /projects/{project_uid}/SpatialSources/{spatialsource_uid} | Removes a spatialsource from a project.
*ProjectsApi* | [**DetachProjectTag**](docs/ProjectsApi.md#detachprojecttag) | **DELETE** /projects/{project_uid}/Tags/{tag} | Removes a tag from a project.
*ProjectsApi* | [**GetConnectedObjectsByProjectUID**](docs/ProjectsApi.md#getconnectedobjectsbyprojectuid) | **GET** /projects/{project_uid}/connectedObjects | Returns an array of connect objects
*ProjectsApi* | [**GetModelsByProjectUID**](docs/ProjectsApi.md#getmodelsbyprojectuid) | **GET** /projects/{project_uid}/Models | Returns the models of a project
*ProjectsApi* | [**GetProjectTagsByProjectUID**](docs/ProjectsApi.md#getprojecttagsbyprojectuid) | **GET** /projects/{project_uid}/Tags | Returns the tags of a project.
*ProjectsApi* | [**GetProjects**](docs/ProjectsApi.md#getprojects) | **GET** /projects | Get a GeoJSON structure containing a list of Projects.
*ProjectsApi* | [**GetProjectsByUID**](docs/ProjectsApi.md#getprojectsbyuid) | **GET** /projects/{project_uid} | Getting single Projects by its UID
*ProjectsApi* | [**GetSpatialSourceByProjectUID**](docs/ProjectsApi.md#getspatialsourcebyprojectuid) | **GET** /projects/{project_uid}/SpatialSources | Returns the SpatialSources of a Project.
*ProjectsApi* | [**NewModelUnderProject**](docs/ProjectsApi.md#newmodelunderproject) | **POST** /projects/{project_uid}/Models | Create a new model
*ProjectsApi* | [**NewProject**](docs/ProjectsApi.md#newproject) | **POST** /projects | Create a new project
*ProjectsApi* | [**NewSpatialSourceUnderProject**](docs/ProjectsApi.md#newspatialsourceunderproject) | **POST** /projects/{project_uid}/SpatialSources | Create a new SpatialSource
*ProjectsApi* | [**UpdateProjects**](docs/ProjectsApi.md#updateprojects) | **PATCH** /projects/{project_uid} | Update a project
*SpatialSourcesApi* | [**DetachSpatialSourceAddDoc**](docs/SpatialSourcesApi.md#detachspatialsourceadddoc) | **DELETE** /spatialsource/{spatialsource_uid}/AdditionalDocument/{adddoc_uid} | Removes an additional document for a spatial source.
*SpatialSourcesApi* | [**GetSpatialSourceAddDocs**](docs/SpatialSourcesApi.md#getspatialsourceadddocs) | **GET** /spatialsource/{spatialsource_uid}/AdditionalDocument | Returns the additional documents of a spatial source
*SpatialSourcesApi* | [**GetSpatialSourceByUID**](docs/SpatialSourcesApi.md#getspatialsourcebyuid) | **GET** /spatialsource/{spatialsource_uid} | Returns a single SpatialSource
*SpatialSourcesApi* | [**GetSpatialSourceSingleAddDoc**](docs/SpatialSourcesApi.md#getspatialsourcesingleadddoc) | **GET** /spatialsource/{spatialsource_uid}/AdditionalDocument/{adddoc_uid} | Returns the additional documents of a spatial source
*SpatialSourcesApi* | [**GetSpatialSources**](docs/SpatialSourcesApi.md#getspatialsources) | **GET** /spatialsources | Returns a list of SpatialSources
*SpatialSourcesApi* | [**NewSpatialSource**](docs/SpatialSourcesApi.md#newspatialsource) | **POST** /spatialsources | Create a new SpatialSource
*SpatialSourcesApi* | [**NewSpatialSourceAddAddDoc**](docs/SpatialSourcesApi.md#newspatialsourceaddadddoc) | **POST** /spatialsource/{spatialsource_uid}/AdditionalDocument | Add a new additional document to a spatial source
*SpatialSourcesApi* | [**PutSpatialSourceByUID**](docs/SpatialSourcesApi.md#putspatialsourcebyuid) | **PUT** /spatialsource/{spatialsource_uid} | Replace an existing SpatialSource by a newer version
*SpatialUnitsApi* | [**Create2PpolygonSPUfromBFS**](docs/SpatialUnitsApi.md#create2ppolygonspufrombfs) | **POST** /spatialunits/create2Dpolygonspatialunit | Creates a spatial unit
*SpatialUnitsApi* | [**GetSpatialUnitByUID**](docs/SpatialUnitsApi.md#getspatialunitbyuid) | **GET** /spatialunits/qualitative/{spatialunit_uid} | Returns a single spatial unit
*SpatialUnitsApi* | [**GetSpatialUnitConceptByUID**](docs/SpatialUnitsApi.md#getspatialunitconceptbyuid) | **GET** /spatialunits/concepts/{concept_uid} | Returns a single spatial unit concept
*SpatialUnitsApi* | [**GetSpatialUnits**](docs/SpatialUnitsApi.md#getspatialunits) | **GET** /spatialunits | Returns a list of SpatialUnits in a GeoJSON structure.
*SpatialUnitsApi* | [**GetSpatialUnitsByUUID**](docs/SpatialUnitsApi.md#getspatialunitsbyuuid) | **GET** /spatialunits/{spatialunit_uid} | Returns a list of SpatialUnits
*SpatialUnitsApi* | [**GetSpatialUnitsConcepts**](docs/SpatialUnitsApi.md#getspatialunitsconcepts) | **GET** /spatialunits/concepts | Returns a list of spatial units concepts
*SpatialUnitsApi* | [**GetSpatialUnitsQualitative**](docs/SpatialUnitsApi.md#getspatialunitsqualitative) | **GET** /spatialunits/qualitative | Returns a list of SpatialUnits
*SpatialUnitsApi* | [**NewSpatialUnit**](docs/SpatialUnitsApi.md#newspatialunit) | **POST** /spatialunits | Create a new SpatialUnit
*SpatialUnitsApi* | [**NewSpatialUnitConcept**](docs/SpatialUnitsApi.md#newspatialunitconcept) | **POST** /spatialunits/concepts | Create a new concept for a spatial unit
*SpatialUnitsApi* | [**NewSpatialUnitQualitative**](docs/SpatialUnitsApi.md#newspatialunitqualitative) | **POST** /spatialunits/qualitative | Create a new SpatialUnit
*SpatialUnitsApi* | [**UpdateSpatialUnit**](docs/SpatialUnitsApi.md#updatespatialunit) | **PATCH** /spatialunits/{spatialunit_uid} | Update an spatial unit
*SpatialUnitsApi* | [**UpdateSpatialUnitConcept**](docs/SpatialUnitsApi.md#updatespatialunitconcept) | **PATCH** /spatialunits/concepts/{concept_uid} | Updates a new spatial unit concept
*SpatialUnitsApi* | [**UpdateSpatialUnitQualitative**](docs/SpatialUnitsApi.md#updatespatialunitqualitative) | **PATCH** /spatialunits/qualitative/{spatialunit_uid} | Updates a new SpatialUnit
*TagsApi* | [**GetTagByName**](docs/TagsApi.md#gettagbyname) | **GET** /tags/{tag_name} | Returns a single tag
*TagsApi* | [**GetTags**](docs/TagsApi.md#gettags) | **GET** /tags | Get a list of tags
*TagsApi* | [**MergeTagByUID**](docs/TagsApi.md#mergetagbyuid) | **PATCH** /tags/{tag_uid}/merge | Merge tags
*TagsApi* | [**UpdateTagByName**](docs/TagsApi.md#updatetagbyname) | **PATCH** /tags/{tag_name} | Updates a tag
*ToolsApi* | [**GetTools**](docs/ToolsApi.md#gettools) | **GET** /tools | Get a list of tools
*TrainingSetsApi* | [**GetTrainingSetByUID**](docs/TrainingSetsApi.md#gettrainingsetbyuid) | **GET** /trainingsets/{trainingsets_uid} | Returns a single TrainingSet
*TrainingSetsApi* | [**GetTrainingSets**](docs/TrainingSetsApi.md#gettrainingsets) | **GET** /trainingsets | Returns a list of TrainingSets
*TrainingSetsApi* | [**NewTrainingSet**](docs/TrainingSetsApi.md#newtrainingset) | **POST** /trainingsets | Create a new TrainingSet
*WP5ValidationSetsApi* | [**GetWP5ValidationSetByUID**](docs/WP5ValidationSetsApi.md#getwp5validationsetbyuid) | **GET** /WP5ValidationSets/{wp5validationset_uid} | Returns a single WP5ValidationSet
*WP5ValidationSetsApi* | [**GetWP5ValidationSets**](docs/WP5ValidationSetsApi.md#getwp5validationsets) | **GET** /WP5ValidationSets | Returns a list of WP5ValidationSets
*WP5ValidationSetsApi* | [**NewWP5ValidationSets**](docs/WP5ValidationSetsApi.md#newwp5validationsets) | **POST** /WP5ValidationSets | Create a new WP5ValidationSets


<a name="documentation-for-models"></a>
## Documentation for Models

 - [Model.AdditionalDocumentsEndpointType](docs/AdditionalDocumentsEndpointType.md)
 - [Model.AdditionalDocumentsPost](docs/AdditionalDocumentsPost.md)
 - [Model.AdminSourcesEndpointType](docs/AdminSourcesEndpointType.md)
 - [Model.AdminSourcesEndpointTypeSpatialUnits](docs/AdminSourcesEndpointTypeSpatialUnits.md)
 - [Model.AdminSourcesPostRequest](docs/AdminSourcesPostRequest.md)
 - [Model.BoundaryFaceStringEndpointType](docs/BoundaryFaceStringEndpointType.md)
 - [Model.BoundaryFaceStringEndpointTypeFeatures](docs/BoundaryFaceStringEndpointTypeFeatures.md)
 - [Model.BoundaryFaceStringEndpointTypeGeometry](docs/BoundaryFaceStringEndpointTypeGeometry.md)
 - [Model.BoundaryFaceStringEndpointTypeProperties](docs/BoundaryFaceStringEndpointTypeProperties.md)
 - [Model.BoundaryFaceStringEndpointTypePropertiesSpatialUnit](docs/BoundaryFaceStringEndpointTypePropertiesSpatialUnit.md)
 - [Model.BoundaryFaceStringPostRequest](docs/BoundaryFaceStringPostRequest.md)
 - [Model.BoundaryFaceStringPostRequestFeatures](docs/BoundaryFaceStringPostRequestFeatures.md)
 - [Model.BoundaryFaceStringPostRequestProperties](docs/BoundaryFaceStringPostRequestProperties.md)
 - [Model.ClassifierEndpointType](docs/ClassifierEndpointType.md)
 - [Model.ClassifierPostRequest](docs/ClassifierPostRequest.md)
 - [Model.ConnectedObjectsEndpointType](docs/ConnectedObjectsEndpointType.md)
 - [Model.ConnectedObjectsEndpointTypeInner](docs/ConnectedObjectsEndpointTypeInner.md)
 - [Model.ContentItemEndpointType](docs/ContentItemEndpointType.md)
 - [Model.DDILayersEndpointType](docs/DDILayersEndpointType.md)
 - [Model.DDILayersPostRequest](docs/DDILayersPostRequest.md)
 - [Model.ImageSetsEndpointType](docs/ImageSetsEndpointType.md)
 - [Model.ImageSetsEndpointTypeContentItems](docs/ImageSetsEndpointTypeContentItems.md)
 - [Model.ImageSetsEndpointTypeMetadata](docs/ImageSetsEndpointTypeMetadata.md)
 - [Model.LogEntryEndpointType](docs/LogEntryEndpointType.md)
 - [Model.LogEntryPostRequest](docs/LogEntryPostRequest.md)
 - [Model.MetricMapFeaturePostRequest](docs/MetricMapFeaturePostRequest.md)
 - [Model.MetricMapFeaturePostRequestProperties](docs/MetricMapFeaturePostRequestProperties.md)
 - [Model.MetricMapFeaturesEndpointType](docs/MetricMapFeaturesEndpointType.md)
 - [Model.MetricMapFeaturesEndpointTypeFeatures](docs/MetricMapFeaturesEndpointTypeFeatures.md)
 - [Model.MetricMapFeaturesEndpointTypeGeometry](docs/MetricMapFeaturesEndpointTypeGeometry.md)
 - [Model.MetricMapFeaturesEndpointTypeProperties](docs/MetricMapFeaturesEndpointTypeProperties.md)
 - [Model.ModelClassesEndpointType](docs/ModelClassesEndpointType.md)
 - [Model.ModelClassesEndpointTypeModel](docs/ModelClassesEndpointTypeModel.md)
 - [Model.ModelClassesPostRequest](docs/ModelClassesPostRequest.md)
 - [Model.ModelsEndpointType](docs/ModelsEndpointType.md)
 - [Model.ModelsEndpointTypeModelClasses](docs/ModelsEndpointTypeModelClasses.md)
 - [Model.ModelsEndpointTypeProjects](docs/ModelsEndpointTypeProjects.md)
 - [Model.ModelsPatchRequest](docs/ModelsPatchRequest.md)
 - [Model.ModelsPostRequest](docs/ModelsPostRequest.md)
 - [Model.ProcessEndpointType](docs/ProcessEndpointType.md)
 - [Model.ProcessEndpointTypeProject](docs/ProcessEndpointTypeProject.md)
 - [Model.ProcessEndpointTypeResults](docs/ProcessEndpointTypeResults.md)
 - [Model.ProcessEndpointTypeTool](docs/ProcessEndpointTypeTool.md)
 - [Model.ProcessEndpointTypeToolEntryPoint](docs/ProcessEndpointTypeToolEntryPoint.md)
 - [Model.ProcessEndpointTypeToolEntryPointParameter](docs/ProcessEndpointTypeToolEntryPointParameter.md)
 - [Model.ProcessPostRequest](docs/ProcessPostRequest.md)
 - [Model.ProcessPostRequestProject](docs/ProcessPostRequestProject.md)
 - [Model.ProcessPostRequestTool](docs/ProcessPostRequestTool.md)
 - [Model.ProcessPostRequestToolEntryPoint](docs/ProcessPostRequestToolEntryPoint.md)
 - [Model.ProjectsEndpointType](docs/ProjectsEndpointType.md)
 - [Model.ProjectsEndpointType2](docs/ProjectsEndpointType2.md)
 - [Model.ProjectsEndpointType2Features](docs/ProjectsEndpointType2Features.md)
 - [Model.ProjectsEndpointType2Properties](docs/ProjectsEndpointType2Properties.md)
 - [Model.ProjectsEndpointTypeCrs](docs/ProjectsEndpointTypeCrs.md)
 - [Model.ProjectsEndpointTypeCrsProperties](docs/ProjectsEndpointTypeCrsProperties.md)
 - [Model.ProjectsEndpointTypeFeatures](docs/ProjectsEndpointTypeFeatures.md)
 - [Model.ProjectsEndpointTypeGeometry](docs/ProjectsEndpointTypeGeometry.md)
 - [Model.ProjectsEndpointTypeProperties](docs/ProjectsEndpointTypeProperties.md)
 - [Model.ProjectsEndpointTypePropertiesModels](docs/ProjectsEndpointTypePropertiesModels.md)
 - [Model.ProjectsEndpointTypePropertiesSpatialSources](docs/ProjectsEndpointTypePropertiesSpatialSources.md)
 - [Model.ProjectsPatchRequest](docs/ProjectsPatchRequest.md)
 - [Model.ProjectsPostRequest](docs/ProjectsPostRequest.md)
 - [Model.ProjectsPostRequestFeatures](docs/ProjectsPostRequestFeatures.md)
 - [Model.ProjectsPostRequestProperties](docs/ProjectsPostRequestProperties.md)
 - [Model.ProjectsPostRequestPropertiesSpatialSources](docs/ProjectsPostRequestPropertiesSpatialSources.md)
 - [Model.PublishAndShareConfigEndpointType](docs/PublishAndShareConfigEndpointType.md)
 - [Model.PublishAndShareConfigEndpointTypeInner](docs/PublishAndShareConfigEndpointTypeInner.md)
 - [Model.RFC6902PatchRequest](docs/RFC6902PatchRequest.md)
 - [Model.RFC6902PatchRequestOrg](docs/RFC6902PatchRequestOrg.md)
 - [Model.RFC6902PatchRequestOrgInner](docs/RFC6902PatchRequestOrgInner.md)
 - [Model.SiteEndpointType](docs/SiteEndpointType.md)
 - [Model.SpatialSourcesEndpointType](docs/SpatialSourcesEndpointType.md)
 - [Model.SpatialSourcesEndpointTypeAdditionalDocuments](docs/SpatialSourcesEndpointTypeAdditionalDocuments.md)
 - [Model.SpatialSourcesPostRequest](docs/SpatialSourcesPostRequest.md)
 - [Model.SpatialUnitBaseFeaturePostRequest](docs/SpatialUnitBaseFeaturePostRequest.md)
 - [Model.SpatialUnitConceptEndpointType](docs/SpatialUnitConceptEndpointType.md)
 - [Model.SpatialUnitConceptPostRequest](docs/SpatialUnitConceptPostRequest.md)
 - [Model.SpatialUnitsFeatureEndpointType](docs/SpatialUnitsFeatureEndpointType.md)
 - [Model.SpatialUnitsFeatureEndpointTypeFeatures](docs/SpatialUnitsFeatureEndpointTypeFeatures.md)
 - [Model.SpatialUnitsFeatureEndpointTypeProperties](docs/SpatialUnitsFeatureEndpointTypeProperties.md)
 - [Model.SpatialUnitsFeatureEndpointTypePropertiesAdminSource](docs/SpatialUnitsFeatureEndpointTypePropertiesAdminSource.md)
 - [Model.SpatialUnitsFeatureEndpointTypePropertiesProjects](docs/SpatialUnitsFeatureEndpointTypePropertiesProjects.md)
 - [Model.SpatialUnitsFeaturePostRequest](docs/SpatialUnitsFeaturePostRequest.md)
 - [Model.SpatialUnitsFeaturePostRequestFeatures](docs/SpatialUnitsFeaturePostRequestFeatures.md)
 - [Model.SpatialUnitsFeaturePostRequestProperties](docs/SpatialUnitsFeaturePostRequestProperties.md)
 - [Model.TagsEndpointType](docs/TagsEndpointType.md)
 - [Model.TagsEndpointTypeTaggedObjects](docs/TagsEndpointTypeTaggedObjects.md)
 - [Model.TagsEndpointTypeTaggedObjectsSum](docs/TagsEndpointTypeTaggedObjectsSum.md)
 - [Model.TagsListResponse](docs/TagsListResponse.md)
 - [Model.TagsPostRequest](docs/TagsPostRequest.md)
 - [Model.ToolsEndpointType](docs/ToolsEndpointType.md)
 - [Model.ToolsEndpointTypeEntryPoints](docs/ToolsEndpointTypeEntryPoints.md)
 - [Model.ToolsEndpointTypeImage](docs/ToolsEndpointTypeImage.md)
 - [Model.TrainingSetsPostRequest](docs/TrainingSetsPostRequest.md)
 - [Model.TrainingsSetEndpointType](docs/TrainingsSetEndpointType.md)
 - [Model.TrainingsSetEndpointTypeModels](docs/TrainingsSetEndpointTypeModels.md)
 - [Model.WP5ValidationSetsEndpointType](docs/WP5ValidationSetsEndpointType.md)
 - [Model.WP5ValidationSetsPostRequest](docs/WP5ValidationSetsPostRequest.md)


<a name="documentation-for-authorization"></a>
## Documentation for Authorization

<a name="api_key"></a>
### api_key

- **Type**: API key
- **API key parameter name**: X-i4lAPIKEY
- **Location**: HTTP header

